/// <reference types="react" />
import { AxiosInstance } from 'axios';
export declare type IAxiosClients = {
    [name: string]: AxiosInstance;
};
/**
 * React context to hold AxiosClientManager instance
 */
export declare const AxiosClientsContext: import("react").Context<AxiosClientsManager>;
/**
 * Used as the IoC container to inject axios client instances into components
 * based on their names
 */
export declare class AxiosClientsManager {
    clients: IAxiosClients;
    constructor(clients: IAxiosClients);
    getClient(key?: string): AxiosInstance;
}
/**
 * Injects axios client from the context based on the provided name or
 * uses the provided instance. If called without arguments, uses the default
 * instance
 *
 * @param clientOrName - name of the axios client to be injected, or instance to be used
 */
export declare function useContextAxiosClient(clientOrName: string | AxiosInstance): AxiosInstance;
