import { createContext, useContext } from 'react';
/**
 * React context to hold AxiosClientManager instance
 */
export var AxiosClientsContext = createContext(null);
/**
 * Used as the IoC container to inject axios client instances into components
 * based on their names
 */
var AxiosClientsManager = /** @class */ (function () {
    function AxiosClientsManager(clients) {
        this.clients = clients;
    }
    AxiosClientsManager.prototype.getClient = function (key) {
        if (key === void 0) { key = 'default'; }
        return this.clients[key];
    };
    return AxiosClientsManager;
}());
export { AxiosClientsManager };
/**
 * Injects axios client from the context based on the provided name or
 * uses the provided instance. If called without arguments, uses the default
 * instance
 *
 * @param clientOrName - name of the axios client to be injected, or instance to be used
 */
export function useContextAxiosClient(clientOrName) {
    var clientsContext = useContext(AxiosClientsContext);
    if (!clientOrName) {
        return clientsContext.getClient();
    }
    else if (typeof clientOrName === 'string') {
        return clientsContext.getClient(clientOrName);
    }
    else {
        return clientOrName;
    }
}
//# sourceMappingURL=AxiosClientsContext.js.map